@@ -7,7 +7,7 @@
 
 
 typedef struct {
-    /* The thingumybob. */
+    /* Options for the quantizer. */
     liq_attr * attr;
     /* The image we are currently processing. */
     liq_image * image;
@@ -15,7 +15,7 @@ typedef struct {
     liq_result * result;
     /* This is the hook for subclasses to hang their data from. */
     void * hook;
-    /* */
+    /* Number of calls to malloc, calloc, etc. */
     int n_mallocs;
     /* Image data stuff. */
     unsigned height;
@@ -295,6 +295,11 @@ image_quantize_png_data_to_rgba (image_quantize_t * iq)
     case PNG_COLOR_TYPE_RGB_ALPHA:
 	break;
 
+    case PNG_COLOR_TYPE_RGB:
+    case PNG_COLOR_TYPE_PALETTE:
+    case PNG_COLOR_TYPE_GRAY:
+    case PNG_COLOR_TYPE_GRAY_ALPHA:
+
     default:
 	image_quantize_perl_error (iq, "colour type %d cannot be handled yet",
 				   colour_type);
@@ -326,6 +331,8 @@ image_quantize_post_quantize (image_quantize_t * iq)
     }
 }
 
+/* Image::Quantize::PNG::quantize ($self) */
+
 static void
 image_quantize_png_quantize (image_quantize_t * iq)
 {
