@@ -1,27 +1,24 @@
+#include <stdlib.h>
+#include <string.h>
+#include <math.h>
+#include <stdbool.h>
 
-#include "libimagequant.h"
 #include "pam.h"
 #include "viter.h"
 #include "nearest.h"
-#include <stdlib.h>
-#include <string.h>
 
-#ifdef _OPENMP
-#include <omp.h>
-#else
 #define omp_get_max_threads() 1
 #define omp_get_thread_num() 0
-#endif
 
 /*
  * Voronoi iteration: new palette color is computed from weighted average of colors that map to that palette entry.
  */
-LIQ_PRIVATE void viter_init(const colormap *map, const unsigned int max_threads, viter_state average_color[])
+ void viter_init(const colormap *map, const unsigned int max_threads, viter_state average_color[])
 {
     memset(average_color, 0, sizeof(average_color[0])*(VITER_CACHE_LINE_GAP+map->colors)*max_threads);
 }
 
-LIQ_PRIVATE void viter_update_color(const f_pixel acolor, const float value, const colormap *map, unsigned int match, const unsigned int thread, viter_state average_color[])
+ void viter_update_color(const f_pixel acolor, const float value, const colormap *map, unsigned int match, const unsigned int thread, viter_state average_color[])
 {
     match += thread * (VITER_CACHE_LINE_GAP+map->colors);
     average_color[match].a += acolor.a * value;
@@ -31,15 +28,15 @@ LIQ_PRIVATE void viter_update_color(const f_pixel acolor, const float value, con
     average_color[match].total += value;
 }
 
-LIQ_PRIVATE void viter_finalize(colormap *map, const unsigned int max_threads, const viter_state average_color[])
+ void viter_finalize(colormap *map, const unsigned int max_threads, const viter_state average_color[])
 {
-    int i;
+    unsigned int i;
     for (i=0; i < map->colors; i++) {
         double a=0, r=0, g=0, b=0, total=0;
+	unsigned int t;
 
         // Aggregate results from all threads
-        int t;
-        for(t=0; t < max_threads; t++) {
+        for (t=0; t < max_threads; t++) {
             const unsigned int offset = (VITER_CACHE_LINE_GAP+map->colors) * t + i;
 
             a += average_color[offset].a;
@@ -61,7 +58,7 @@ LIQ_PRIVATE void viter_finalize(colormap *map, const unsigned int max_threads, c
     }
 }
 
-LIQ_PRIVATE double viter_do_iteration(histogram *hist, colormap *const map, const float min_opaque_val, viter_callback callback, const bool fast_palette)
+ double viter_do_iteration(histogram *hist, colormap *const map, const float min_opaque_val, viter_callback callback, const bool fast_palette)
 {
     const unsigned int max_threads = omp_get_max_threads();
     viter_state average_color[(VITER_CACHE_LINE_GAP+map->colors) * max_threads];
@@ -69,6 +66,7 @@ LIQ_PRIVATE double viter_do_iteration(histogram *hist, colormap *const map, cons
     struct nearest_map *const n = nearest_init(map, fast_palette);
     hist_item *const achv = hist->achv;
     const int hist_size = hist->size;
+    int j;
 
     double total_diff=0;
 #ifdef _OPENMP
@@ -76,7 +74,6 @@ LIQ_PRIVATE double viter_do_iteration(histogram *hist, colormap *const map, cons
         default(none) shared(average_color,callback) reduction(+:total_diff)
 #endif /* def _OPENMP */
 
-    int j;
     for(j=0; j < hist_size; j++) {
         float diff;
         unsigned int match = nearest_search(n, achv[j].acolor, achv[j].likely_colormap_index, min_opaque_val, &diff);
